@@ -101,7 +101,7 @@ License and Copyright
 
 ASL 2.0
 
-Copyright (C) CERN 2011-2013
+Copyright (C) CERN 2011-2014
 """
 
 import errno
@@ -365,7 +365,12 @@ class QueueSimple(QueueBase):
                                                (TEMPORARY_SUFFIX,
                                                 LOCKED_SUFFIX), x)]
                 for old in tmp_lock_elems:
-                    stat = os.stat('%s/%s' % (path, old))
+                    try:
+                        stat = os.stat('%s/%s' % (path, old))
+                    except OSError:
+                        error = sys.exc_info()[1]
+                        if error.errno != errno.ENOENT:
+                            raise error
                     if (old.endswith(TEMPORARY_SUFFIX) and
                             stat.st_mtime >= oldtemp):
                         continue
@@ -374,7 +379,12 @@ class QueueSimple(QueueBase):
                         continue
                     _warn("WARNING: removing too old volatile file: %s/%s" %
                           (self.path, old))
-                    os.unlink('%s/%s' % (path, old))
+                    try:
+                        os.unlink('%s/%s' % (path, old))
+                    except OSError:
+                        error = sys.exc_info()[1]
+                        if error.errno != errno.ENOENT:
+                            raise error
         # try to purge all but the last intermediate directory
         if len(dirs) > 1:
             dirs.sort()
